#
# spec file for package ecryptfs-utils
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           ecryptfs-utils
Url:            https://launchpad.net/ecryptfs
License:        GPLv2+
Group:          Productivity/Security
AutoReqProv:    on
Summary:        Userspace Utilities for ecryptfs
Version:        83
Release:        6.9.1
Source0:        http://launchpad.net/ecryptfs/trunk/%version/+download/ecryptfs-utils_%version.orig.tar.gz
Source1:        baselibs.conf
Patch0:         CVE-2011-1831,1832,1834.patch
Patch1:         CVE-2011-1833.patch
Patch2:         CVE-2011-1835.patch
Patch4:         CVE-2011-1837.patch
Patch5:         ecryptfs-utils-CVE-2011-3145.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gtk2-devel intltool keyutils-devel keyutils-libs libgcrypt-devel mozilla-nss-devel openssl-devel pam-devel pkcs11-helper-devel python-devel trousers-devel
BuildRequires:  update-desktop-files

%description
A stacked cryptographic filesystem for Linux.



Authors:
--------
    Mike Halcrow designed and implemented eCryptfs, which is a fork from
    Cryptfs. Erez Zadok, along with the fileystem research lab at Stony
    Brook University, designed and implemented Cryptfs. Michael
    C. Thompson has contributed a substantial amount of code to the
    project.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1

%build
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
autoreconf -i -f
%configure \
	--docdir=%_defaultdocdir/%{name} \
	--disable-static \
	--enable-tspi \
	--enable-pkcs11-helper \
	--with-pamdir=/%_lib/security

%check
make
make check

%install
%makeinstall
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/applications/
mv $RPM_BUILD_ROOT/%{_datadir}/ecryptfs-utils/*desktop $RPM_BUILD_ROOT/%{_datadir}/applications/
%suse_update_desktop_file ecryptfs-mount-private
%suse_update_desktop_file ecryptfs-setup-private
%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-, root, root)
%doc COPYING NEWS README THANKS doc/ecryptfs-faq.html doc/ecryptfs-pam-doc.txt
/usr/include/ecryptfs.h
%{_prefix}/bin/*
/sbin/*
%{_libdir}/libecryptfs*
%{_libdir}/pkgconfig/libecryptfs.pc
%{_mandir}/man1/*ecryptfs*
%{_mandir}/man7/ecryptfs*
%{_mandir}/man8/*ecryptfs*
%{_libdir}/ecryptfs*
%{_datadir}/ecryptfs-utils
/%_lib/security/pam_ecryptfs.so
%{python_sitelib}/ecryptfs-utils
%{python_sitearch}/ecryptfs-utils
%{_datadir}/applications/ecryptfs-*

%changelog
* Wed Dec 14 2011 meissner@suse.de
- Fixed umask of /etc/mtab.tmp and get / drop group rights
  before/after failed mounting. bnc#735342 / CVE-2011-3145
* Thu Aug 11 2011 meissner@suse.de
- Various security fixes (bnc#709771)
  CVE-2011-1831 - Race condition when checking mountpoint during mount.
  CVE-2011-1832 - Race condition when checking mountpoint during unmount.
  CVE-2011-1833 - Race condition when checking source during mount.
  CVE-2011-1834 - Improper mtab handling allowing corruption due to resource
  limits, signals, etc.
  CVE-2011-1835 - Key poisoning in ecryptfs-setup-private due to insecure temp
  directory.
  CVE-2011-1837 - Predictable lock counter name and associated races.
* Sat Apr 10 2010 aj@suse.de
- Fix build with adding requires on mozilla-nss-devel and python-devel.
- Fix package list.
* Thu Mar 18 2010 meissner@suse.de
- Updated to 83
  - lots of bugfixes
  - improvements
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Jun 25 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Fri Oct 24 2008 meissner@suse.de
- Upgraded to version 61
  - starts of filename encryption
  - bugfixes
* Fri Sep 19 2008 meissner@suse.de
- Upgraded to version 58
  - config file changes yet again
  - some documentation fixes
  - some TPM related fixes
* Sat Aug 23 2008 meissner@suse.de
- Upgraded to version 56
  - more manpages
  - changed configfile format
* Fri Jul 11 2008 meissner@suse.de
- Upgraded to version 50
  - another manpage
  - bugfixes
  - fixed kernel netlink interface
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 meissner@suse.de
- Upgraded to version 41
  - typo fixed in manpage
- enabled TPM support (tspi)
- enabled PKCS11 support
* Mon Feb 25 2008 meissner@suse.de
- Upgraded to version 40
  - more manpages
  - some new features
  - lots of bugfixes
* Fri Aug  3 2007 meissner@suse.de
- fixed pam module path for ia64 and s390x too.
* Sun Jul 29 2007 meissner@suse.de
- fixed pam module path
* Fri Jul 27 2007 meissner@suse.de
- uphgraded to version 18.
  - TPM support (not yet enabled)
  - added PAM module
* Tue Mar 20 2007 meissner@suse.de
- build on IA64
- fixed compiler warnings
* Tue Mar  6 2007 meissner@suse.de
- fixed build on lib64
* Mon Mar  5 2007 meissner@suse.de
- upgraded to version 10.
  - unlisted enhancements and bugfixes.
* Thu Dec 14 2006 meissner@suse.de
- use lib64 correctly.
- fixed "is used uninitialized" warnings.
* Tue Dec  5 2006 meissner@suse.de
- initial checkin of version 5.
  - userland utilities to control ecryptfs filesystems
